bb_get_one_side: Get the coordinates for half-court graphics.

Description Usage Arguments

Description

bb_get_one_side returns a dataframe which has two new columns representing transformed xy coordinates intended to make half court graphics easier to make.

Usage

1
bb_get_one_side(data, x_col, y_col)

Arguments

data

a dataframe

x_col

a column of x coordinates

y_col

a column of y coordinates


mistermichaelll/statcrewRC documentation built on June 1, 2019, 3:57 a.m.