bb_get_one_side returns a dataframe which has two new columns representing
transformed xy coordinates intended to make half court graphics easier to make.
1 | bb_get_one_side(data, x_col, y_col)
|
data |
a dataframe |
x_col |
a column of x coordinates |
y_col |
a column of y coordinates |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.